document.addEventListener('DOMContentLoaded', () => {
    const oldNameInput = document.getElementById('oldName');
    const newNameInput = document.getElementById('newName');
    const submitBtn = document.getElementById('submitBtn');
    const clearAllBtn = document.getElementById('clearAllBtn');
    const replacementList = document.getElementById('replacementList');

    // load and display current replacements
    function loadReplacements() {
        chrome.storage.local.get(['replacements'], (result) => {
            const replacements = result.replacements || [];
            replacementList.innerHTML = '';
            replacements.forEach((replacement, index) => {
                const listItem = document.createElement('li');
                listItem.innerHTML = `
                    <span>${replacement.oldName} → ${replacement.newName}</span>
                    <button class="deleteBtn" data-index="${index}">Delete</button>
                `;
                replacementList.appendChild(listItem);
            });

            // Add event listeners for delete buttons
            document.querySelectorAll('.deleteBtn').forEach(button => {
                button.addEventListener('click', () => {
                    const index = parseInt(button.getAttribute('data-index'), 10);
                    removeReplacement(index);
                });
            });
        });
    }

    // Add a new replacement
    function addReplacement() {
        const oldName = oldNameInput.value.trim();
        const newName = newNameInput.value.trim();

        if (oldName && newName) {
            chrome.storage.local.get(['replacements'], (result) => {
                const replacements = result.replacements || [];
                replacements.push({ oldName, newName });
                chrome.storage.local.set({ replacements }, () => {
                    oldNameInput.value = '';
                    newNameInput.value = '';
                    loadReplacements(); // Refresh the list
                });
            });
        }
    }

    // Remove a replacement
    function removeReplacement(index) {
        chrome.storage.local.get(['replacements'], (result) => {
            const replacements = result.replacements || [];
            replacements.splice(index, 1);
            chrome.storage.local.set({ replacements }, () => {
                loadReplacements(); // Refresh the list
            });
        });
    }

    // Clear all replacements
    function clearAll() {
        chrome.storage.local.set({ replacements: [] }, () => {
            loadReplacements(); // Refresh the list
        });
    }

    // Set up event listeners
    submitBtn.addEventListener('click', addReplacement);
    clearAllBtn.addEventListener('click', clearAll);

    // Load initial replacements
    loadReplacements();
});
